@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: MIT
-// Copyright (c) 2018-2023, Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2018-2024, Advanced Micro Devices, Inc. All rights reserved.
 
 #pragma once
 
@@ -25,6 +25,9 @@ template <ck::index_t NDimSpatial,
           typename InElementwiseOperation,
           typename WeiElementwiseOperation,
           typename OutElementwiseOperation,
+          ck::index_t NumAElementwiseTensor                                         = 0,
+          ck::index_t NumBElementwiseTensor                                         = 0,
+          ck::index_t NumDElementwiseTensor                                         = 0,
           typename ComputeTypeA                                                     = OutDataType,
           typename ComputeTypeB                                                     = InDataType,
           typename std::enable_if<NDimSpatial >= 1 && NDimSpatial <= 3, bool>::type = false>
@@ -33,19 +36,26 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
     // Argument
     struct Argument : public device::BaseArgument
     {
-        Argument(const Tensor<InDataType>& in_n_c_hi_wi,
-                 Tensor<WeiDataType>& wei_k_c_y_x,
-                 const Tensor<OutDataType>& out_n_k_ho_wo,
-                 std::vector<ck::index_t> conv_filter_strides,
-                 std::vector<ck::index_t> conv_filter_dilations,
-                 std::vector<ck::index_t> input_left_pads,
-                 std::vector<ck::index_t> input_right_pads,
-                 InElementwiseOperation in_element_op,
-                 WeiElementwiseOperation wei_element_op,
-                 OutElementwiseOperation out_element_op)
+        Argument(
+            const Tensor<InDataType>& in_n_c_hi_wi,
+            Tensor<WeiDataType>& wei_k_c_y_x,
+            const Tensor<OutDataType>& out_n_k_ho_wo,
+            std::vector<ck::long_index_t> conv_filter_strides,
+            std::vector<ck::long_index_t> conv_filter_dilations,
+            std::vector<ck::long_index_t> input_left_pads,
+            std::vector<ck::long_index_t> input_right_pads,
+            InElementwiseOperation in_element_op,
+            WeiElementwiseOperation wei_element_op,
+            OutElementwiseOperation out_element_op,
+            const std::array<Tensor<OutDataType>, NumAElementwiseTensor>& elementwise_a_tensors,
+            const std::array<Tensor<InDataType>, NumBElementwiseTensor>& elementwise_b_tensors,
+            const std::array<Tensor<WeiDataType>, NumDElementwiseTensor>& elementwise_d_tensors)
             : input_{in_n_c_hi_wi},
               weight_{wei_k_c_y_x},
               output_{out_n_k_ho_wo},
+              elementwise_a_tensors_{elementwise_a_tensors},
+              elementwise_b_tensors_{elementwise_b_tensors},
+              elementwise_d_tensors_{elementwise_d_tensors},
               conv_strides_{conv_filter_strides},
               conv_dilations_{conv_filter_dilations},
               in_left_pads_{input_left_pads},
@@ -60,10 +70,14 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
         Tensor<WeiDataType>& weight_;
         const Tensor<OutDataType>& output_;
 
-        std::vector<index_t> conv_strides_;
-        std::vector<index_t> conv_dilations_;
-        std::vector<index_t> in_left_pads_;
-        std::vector<index_t> in_right_pads_;
+        const std::array<Tensor<OutDataType>, NumAElementwiseTensor>& elementwise_a_tensors_;
+        const std::array<Tensor<InDataType>, NumBElementwiseTensor>& elementwise_b_tensors_;
+        const std::array<Tensor<WeiDataType>, NumDElementwiseTensor>& elementwise_d_tensors_;
+
+        std::vector<long_index_t> conv_strides_;
+        std::vector<long_index_t> conv_dilations_;
+        std::vector<long_index_t> in_left_pads_;
+        std::vector<long_index_t> in_right_pads_;
 
         InElementwiseOperation in_element_op_;
         WeiElementwiseOperation wei_element_op_;
@@ -103,22 +117,43 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
                                 ComputeTypeA v_out;
                                 ComputeTypeB v_in;
 
-                                arg.out_element_op_(
-                                    v_out, ck::type_convert<float>(arg.output_(g, n, k, wo)));
-
-                                arg.in_element_op_(
-                                    v_in, ck::type_convert<float>(arg.input_(g, n, c, wi)));
+                                ExecuteElementwiseOp(
+                                    arg.out_element_op_,
+                                    arg.elementwise_a_tensors_,
+                                    Number<NumAElementwiseTensor>{},
+                                    v_out,
+                                    ck::type_convert<float>(arg.output_(g, n, k, wo)),
+                                    g,
+                                    n,
+                                    k,
+                                    wo);
+                                ExecuteElementwiseOp(
+                                    arg.in_element_op_,
+                                    arg.elementwise_b_tensors_,
+                                    Number<NumBElementwiseTensor>{},
+                                    v_in,
+                                    ck::type_convert<float>(arg.input_(g, n, c, wi)),
+                                    g,
+                                    n,
+                                    c,
+                                    wi);
 
                                 v_acc += type_convert<float>(v_out) * type_convert<float>(v_in);
                             }
                         }
                     }
 
-                    float v_wei;
-
-                    arg.wei_element_op_(v_wei, v_acc);
-
-                    arg.weight_(g, k, c, x) = ck::type_convert<WeiDataType>(v_wei);
+                    WeiDataType v_acc_converted = ck::type_convert<WeiDataType>(v_acc);
+                    WeiDataType& v_wei          = arg.weight_(g, k, c, x);
+                    ExecuteElementwiseOp(arg.wei_element_op_,
+                                         arg.elementwise_d_tensors_,
+                                         Number<NumDElementwiseTensor>{},
+                                         v_wei,
+                                         v_acc_converted,
+                                         g,
+                                         k,
+                                         c,
+                                         x);
                 };
 
                 make_ParallelTensorFunctor(f_kcx,
@@ -163,12 +198,28 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
                                     ComputeTypeA v_out;
                                     ComputeTypeB v_in;
 
-                                    arg.out_element_op_(
+                                    ExecuteElementwiseOp(
+                                        arg.out_element_op_,
+                                        arg.elementwise_a_tensors_,
+                                        Number<NumAElementwiseTensor>{},
                                         v_out,
-                                        ck::type_convert<float>(arg.output_(g, n, k, ho, wo)));
-
-                                    arg.in_element_op_(
-                                        v_in, ck::type_convert<float>(arg.input_(g, n, c, hi, wi)));
+                                        ck::type_convert<float>(arg.output_(g, n, k, ho, wo)),
+                                        g,
+                                        n,
+                                        k,
+                                        ho,
+                                        wo);
+                                    ExecuteElementwiseOp(
+                                        arg.in_element_op_,
+                                        arg.elementwise_b_tensors_,
+                                        Number<NumBElementwiseTensor>{},
+                                        v_in,
+                                        ck::type_convert<float>(arg.input_(g, n, c, hi, wi)),
+                                        g,
+                                        n,
+                                        c,
+                                        hi,
+                                        wi);
 
                                     v_acc += type_convert<float>(v_out) * type_convert<float>(v_in);
                                 }
@@ -176,11 +227,18 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
                         }
                     }
 
-                    float v_wei;
-
-                    arg.wei_element_op_(v_wei, v_acc);
-
-                    arg.weight_(g, k, c, y, x) = ck::type_convert<WeiDataType>(v_wei);
+                    WeiDataType v_acc_converted = ck::type_convert<WeiDataType>(v_acc);
+                    WeiDataType& v_wei          = arg.weight_(g, k, c, y, x);
+                    ExecuteElementwiseOp(arg.wei_element_op_,
+                                         arg.elementwise_d_tensors_,
+                                         Number<NumDElementwiseTensor>{},
+                                         v_wei,
+                                         v_acc_converted,
+                                         g,
+                                         k,
+                                         c,
+                                         y,
+                                         x);
                 };
 
                 make_ParallelTensorFunctor(f_kcyx,
@@ -231,13 +289,30 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
                                         ComputeTypeA v_out;
                                         ComputeTypeB v_in;
 
-                                        arg.out_element_op_(v_out,
-                                                            ck::type_convert<float>(
-                                                                arg.output_(g, n, k, do_, ho, wo)));
-
-                                        arg.in_element_op_(v_in,
-                                                           ck::type_convert<float>(
-                                                               arg.input_(g, n, c, di, hi, wi)));
+                                        ExecuteElementwiseOp(arg.out_element_op_,
+                                                             arg.elementwise_a_tensors_,
+                                                             Number<NumAElementwiseTensor>{},
+                                                             v_out,
+                                                             ck::type_convert<float>(
+                                                                 arg.output_(g, n, k, do_, ho, wo)),
+                                                             g,
+                                                             n,
+                                                             k,
+                                                             do_,
+                                                             ho,
+                                                             wo);
+                                        ExecuteElementwiseOp(arg.in_element_op_,
+                                                             arg.elementwise_b_tensors_,
+                                                             Number<NumBElementwiseTensor>{},
+                                                             v_in,
+                                                             ck::type_convert<float>(
+                                                                 arg.input_(g, n, c, di, hi, wi)),
+                                                             g,
+                                                             n,
+                                                             c,
+                                                             di,
+                                                             hi,
+                                                             wi);
 
                                         v_acc +=
                                             type_convert<float>(v_out) * type_convert<float>(v_in);
@@ -247,11 +322,19 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
                         }
                     }
 
-                    float v_wei;
-
-                    arg.wei_element_op_(v_wei, v_acc);
-
-                    arg.weight_(g, k, c, z, y, x) = ck::type_convert<WeiDataType>(v_wei);
+                    WeiDataType v_acc_converted = ck::type_convert<WeiDataType>(v_acc);
+                    WeiDataType& v_wei          = arg.weight_(g, k, c, z, y, x);
+                    ExecuteElementwiseOp(arg.wei_element_op_,
+                                         arg.elementwise_d_tensors_,
+                                         Number<NumDElementwiseTensor>{},
+                                         v_wei,
+                                         v_acc_converted,
+                                         g,
+                                         k,
+                                         c,
+                                         z,
+                                         y,
+                                         x);
                 };
 
                 make_ParallelTensorFunctor(f_kczyx,
@@ -276,6 +359,37 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
         }
     };
 
+    template <typename... Args,
+              typename ElementwiseOp,
+              typename ElementwiseTensor,
+              typename NumTensor,
+              typename Y,
+              typename X>
+    static void ExecuteElementwiseOp(ElementwiseOp& elementwise_op,
+                                     ElementwiseTensor& elementwise_tensors,
+                                     NumTensor,
+                                     Y& y,
+                                     const X& x,
+                                     Args... dims)
+    {
+        if constexpr(NumTensor::value == 0)
+        {
+            elementwise_op(y, x);
+        }
+        else if constexpr(NumTensor::value == 1)
+        {
+            elementwise_op(y, x, elementwise_tensors[0](dims...));
+        }
+        else if constexpr(NumTensor::value == 2)
+        {
+            elementwise_op(y, x, elementwise_tensors[0](dims...), elementwise_tensors[1](dims...));
+        }
+        else
+        {
+            throw std::runtime_error("ElementOp not supported in reference.");
+        }
+    }
+
     static constexpr bool IsValidCompilationParameter()
     {
         // TODO: properly implement this check
@@ -284,16 +398,20 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
 
     bool IsSupportedArgument(const device::BaseArgument*) override { return true; }
 
-    static auto MakeArgument(const Tensor<InDataType>& in_n_c_hi_wi,
-                             Tensor<WeiDataType>& wei_k_c_y_x,
-                             const Tensor<OutDataType>& out_n_k_ho_wo,
-                             std::vector<ck::index_t> conv_filter_strides,
-                             std::vector<ck::index_t> conv_filter_dilations,
-                             std::vector<ck::index_t> input_left_pads,
-                             std::vector<ck::index_t> input_right_pads,
-                             InElementwiseOperation in_element_op,
-                             WeiElementwiseOperation wei_element_op,
-                             OutElementwiseOperation out_element_op)
+    static auto MakeArgument(
+        const Tensor<InDataType>& in_n_c_hi_wi,
+        Tensor<WeiDataType>& wei_k_c_y_x,
+        const Tensor<OutDataType>& out_n_k_ho_wo,
+        std::vector<ck::long_index_t> conv_filter_strides,
+        std::vector<ck::long_index_t> conv_filter_dilations,
+        std::vector<ck::long_index_t> input_left_pads,
+        std::vector<ck::long_index_t> input_right_pads,
+        InElementwiseOperation in_element_op,
+        WeiElementwiseOperation wei_element_op,
+        OutElementwiseOperation out_element_op,
+        const std::array<Tensor<OutDataType>, NumAElementwiseTensor>& elementwise_a_tensors = {},
+        const std::array<Tensor<InDataType>, NumBElementwiseTensor>& elementwise_b_tensors  = {},
+        const std::array<Tensor<WeiDataType>, NumDElementwiseTensor>& elementwise_d_tensors = {})
     {
         return Argument{in_n_c_hi_wi,
                         wei_k_c_y_x,
@@ -304,7 +422,10 @@ struct ReferenceConvBwdWeight : public device::BaseOperator
                         input_right_pads,
                         in_element_op,
                         wei_element_op,
-                        out_element_op};
+                        out_element_op,
+                        elementwise_a_tensors,
+                        elementwise_b_tensors,
+                        elementwise_d_tensors};
     }
 
     static auto MakeInvoker() { return Invoker{}; }
